==> rad_textures-1.0.21.tar.gz: tool/volume_textures.dart <==
import 'package:rad_textures/rad_textures.dart';
import 'package:vector_math/vector_math.dart';
import 'package:image/image.dart';
import 'dart:io';

main(List<String> args) {
  const int width = 1024;
  const double scale = 0.013;
  const double z = 0.0;

  {
    Image image = new Image(width, width);
    for (int x = 0; x < width; x++)
      for (int y = 0; y < width; y++) {
      double val = noise3(x * scale, y * scale, z);
      val += 1.0;
      val /= 2.0;
      val *= 255;
      image.setPixelRGBA(x, y, 0, val.toInt(), 0, 255);
    }
    new File("/tmp/test.image.jpg")..writeAsBytesSync(encodeJpg(image));
  }
  {
    Image image = new Image(width, width);
    Vector3 normal = new Vector3.zero();
    const double epsilon = 0.1;
    for (int x = 0; x < width; x++) {
      for (int y = 0; y < width; y++) {
        double sample_0 = noise3(x * scale, y * scale, z + 0.0);
        double sample_x = noise3((x + epsilon) * scale, y * scale, z + 0.0);
        double sample_y = noise3(x * scale, (y + epsilon) * scale, z + 0.0);
        double sample_z = noise3(x * scale, y * scale, z + epsilon * scale);
        normal.setValues((sample_x - sample_0) / epsilon,
            (sample_y - sample_0) / epsilon, (sample_z - sample_0) / epsilon);
        normal.normalize();
        image.setPixelRGBA(x, y, map_double_to_int(normal.x),
            map_double_to_int(normal.y), map_double_to_int(normal.z), 255);
      }
    }
    new File("/tmp/test.bump.jpg")..writeAsBytesSync(encodeJpg(image));
  }
}

==> rad_textures-2.0.0.tar.gz: tool/volume_textures.dart <==
import 'package:rad_textures/rad_textures.dart';
import 'package:vector_math/vector_math.dart';
import 'package:image/image.dart' as img;
import 'dart:io';

main(List<String> args) {
  const int width = 1024;
  const double scale = 0.013;
  const double z = 0.0;

  {
    var image = new img.Image(width, width);
    for (int x = 0; x < width; x++)
      for (int y = 0; y < width; y++) {
      double val = noise3(x * scale, y * scale, z);
      val += 1.0;
      val /= 2.0;
      val *= 255;
      image.setPixelRgba(x, y, 0, val.toInt(), 0, 255);
    }
    new File("/tmp/test.image.jpg")..writeAsBytesSync(img.encodeJpg(image));
  }
  {
    var image = new img.Image(width, width);
    Vector3 normal = new Vector3.zero();
    const double epsilon = 0.1;
    for (int x = 0; x < width; x++) {
      for (int y = 0; y < width; y++) {
        double sample_0 = noise3(x * scale, y * scale, z + 0.0);
        double sample_x = noise3((x + epsilon) * scale, y * scale, z + 0.0);
        double sample_y = noise3(x * scale, (y + epsilon) * scale, z + 0.0);
        double sample_z = noise3(x * scale, y * scale, z + epsilon * scale);
        normal.setValues((sample_x - sample_0) / epsilon,
            (sample_y - sample_0) / epsilon, (sample_z - sample_0) / epsilon);
        normal.normalize();
        image.setPixelRgba(x, y, map_double_to_int(normal.x),
            map_double_to_int(normal.y), map_double_to_int(normal.z), 255);
      }
    }
    new File("/tmp/test.bump.jpg")..writeAsBytesSync(img.encodeJpg(image));
  }
}
